@@ -12,6 +12,7 @@ OC.L10N.register(
     "To Do" : "Задачи",
     "Later" : "По-късно",
     "Mail" : "Поща",
+    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "В момента използвате {percentage}от квотата на пощенската си кутия. Моля, освободете пространство като изтриете ненужни съобщения.",
     "Mails" : "Пощи",
     "💌 A mail app for Nextcloud" : "💌 Приложение за поща за Nextcloud",
     "Your session has expired. The page will be reloaded." : "Сесията ви е изтекла. Страницата ще бъде заредена отново.",
@@ -75,6 +76,7 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Автоматичен отговор на входящите съобщения. Ако някой ви изпрати няколко съобщения, този автоматичен отговор ще бъде изпращан най-много веднъж на всеки 4 дни.",
     "Filters" : "Филтри",
     "Mail server" : "Имейл сървър",
+    "Mailbox search" : "Търсене в пощата",
     "Update alias" : "Актуализиране на псевдоним",
     "Rename alias" : "Преименуване на псевдоним",
     "Show update alias form" : "Показване на формуляр за актуализиране на псевдоним",
@@ -88,6 +90,7 @@ OC.L10N.register(
     "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
     "Could not update preference" : "Предпочитанието не можа да се актуализира",
     "Mail settings" : "Настройки на пощата",
+    "Accounts" : "Профили",
     "Add mail account" : "Добавяне на профил",
     "General" : "Общи",
     "List" : "Списък",
@@ -144,15 +147,16 @@ OC.L10N.register(
     "Write message …" : "Писане на съобщение ...",
     "Saving draft …" : "Записване на чернова …",
     "Error saving draft" : "Грешка при запазване на черновата",
-    "Draft saved" : "Черновата записана",
+    "Draft saved" : "Черновата е записана",
     "Save draft" : "Запиши чернова",
     "Discard & close draft" : "Отхвърляне и затворяне на черновата",
     "Enable formatting" : "Форматиран текст",
     "Disable formatting" : "Деактивиране на форматирането",
-    "Upload attachment" : "Качи прикачен файл/ове",
+    "Upload attachment" : "Прикачи файл",
     "Add attachment from Files" : "Прикачи от \"Файлове\"",
-    "Smart picker" : "Смарт /интелигентен/ инструмент за избор",
-    "Request a read receipt" : "Заявка на разписка за четене",
+    "Add share link from Files" : "Сподели връзка от \"Файлове\"",
+    "Smart picker" : "Умно избиране",
+    "Request a read receipt" : "Заявка на разписка за прочитане",
     "Sign message with S/MIME" : "Подписване на съобщение със S/MIME/сертификат/",
     "Encrypt message with S/MIME" : "Криптиране на съобщение със S/MIME",
     "Encrypt message with Mailvelope" : "Криптиране на съобщение с Mailvelope",
@@ -173,6 +177,10 @@ OC.L10N.register(
     "No messages" : "Няма съобщения.",
     "Blind copy recipients only" : "Само получателите на слепи копия",
     "No subject" : "Без /няма/ тема",
+    "Later today – {timeLocale}" : "По-късно днес - {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Утре - {timeLocale}",
+    "This weekend – {timeLocale}" : "Този уикенд - {timeLocale}",
+    "Next week – {timeLocale}" : "Следващата седмица - {timeLocale}",
     "No trash mailbox configured" : "Няма конфигурирана пощенска кутия за боклук",
     "Could not delete message" : "Съобщението не може да бъде изтрито",
     "Could not archive message" : "Не можа да се архивира съобщение",
@@ -185,7 +193,7 @@ OC.L10N.register(
     "Read" : "Прочитане",
     "Unimportant" : "Маловажно",
     "Mark not spam" : "Маркиране, че не е спам",
-    "Mark as spam" : "Маркира като спам",
+    "Mark as spam" : "Маркирай като спам",
     "Edit tags" : "Редактиране на етикетите",
     "Move thread" : "Преместване на нишката",
     "Archive thread" : "Архивна нишка",
@@ -206,12 +214,15 @@ OC.L10N.register(
     "_Unfavorite {number}_::_Unfavorite {number}_" : ["Премахване от любими {number}","Премахване от любими {number}"],
     "_Favorite {number}_::_Favorite {number}_" : ["Любими {number}","Любими {number}"],
     "_Unselect {number}_::_Unselect {number}_" : ["Любими {number}"," Отмяна на избора {number}"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Маркирай {number} като спам","Маркирай {number} като спам"],
+    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number} не са спам","{number}не е спам "],
     "_Move {number} thread_::_Move {number} threads_" : ["Преместване на {number} нишки","Преместване на {number} нишки"],
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препращане {number} като прикачен файл","Препращане {number} като прикачен файл"],
     "Report this bug" : "Докладване на тази грешка",
     "Event created" : "Събитието е създадено",
     "Could not create event" : "Несупешно създаване на събитие",
     "All day" : "Цял ден",
+    "Description" : "Описание",
     "Create" : "Създаване",
     "This event was updated" : "Това събитие беше актуализирано",
     "{attendeeName} accepted your invitation" : "{attendeeName} прие вашата покана",
@@ -332,7 +343,8 @@ OC.L10N.register(
     "Send anyway" : " Все пак го изпратете",
     "Autoresponder off" : "Автоматичният отговор е изключен",
     "Autoresponder on" : "Автоматичният отговор е включен",
-    "First day" : "Първи ден",
+    "Edit absence settings" : "Промени настройките на отсъствието",
+    "First day" : "От",
     "Last day (optional)" : "Последен ден (по избор)",
     "${subject} will be replaced with the subject of the message you are responding to" : "${subject} ще бъде заменена с темата на съобщението, на което отговаряте",
     "Message" : "Съобщение",
@@ -368,6 +380,7 @@ OC.L10N.register(
     "Select tags" : "Избор на етикети",
     "Marked as" : "Маркиран/о като",
     "Has attachments" : "Има прикачени файлове",
+    "Last 7 days" : "Последни 7 дни",
     "Sieve Port" : "Порт на Сито",
     "Custom" : "Персонализиран",
     "Sieve User" : "Потребител на Сито",
@@ -421,9 +434,10 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Влак от {depStation} до {arrStation}",
     "Train" : "Влак",
     "Flag" : "Знаме",
+    "Recipient" : "Получател",
     "Operator" : "Оператор",
-    "Actions" : "Действия",
-    "New action" : "Ново действие",
+    "contains" : "съдържа",
+    "matches" : "съвпадения",
     "Priority" : "Приоритет",
     "Successfully updated config for \"{domain}\"" : "Конфигурацията за „{domain}“ беше актуализирана успешно",
     "Error saving config" : "Грешка при записване на конфигурацията",
@@ -556,7 +570,7 @@ OC.L10N.register(
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
     "Continue to %s" : "Продължи към %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft позволява на потребителите да имат достъп до електронната си поща чрез IMAP. От съображения за сигурност този достъп е възможен само с връзка OAuth 2.0.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Трябва да регистрирате ново приложение в портала на Microsoft Azure Active Directory. Добавете URL адреса {url}, като URI адрес за пренасочване."
+    "Actions" : "Действия",
+    "New action" : "Ново действие"
 },
 "nplurals=2; plural=(n != 1);");
