@@ -94,7 +94,7 @@ OC.L10N.register(
     "Not found" : "Heb ei ganfod",
     "Untitled event" : "Digwyddiad di-deitl",
     "(organizer)" : "(trefnydd)",
-    "Actions" : "Gweithredoedd",
+    "Recipient" : "Derbynnydd",
     "User" : "User",
     "Certificate" : "Tystysgrif",
     "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
@@ -119,6 +119,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
-    "Continue to %s" : "Parhau i %s"
+    "Continue to %s" : "Parhau i %s",
+    "Actions" : "Gweithredoedd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
