@@ -346,11 +346,11 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}",
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}",
     "Train" : "Tog",
+    "Recipient" : "Modtager",
     "New filter" : "Nyt filter",
     "Operator" : "Operatør",
-    "New test" : "Nyeste test",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling",
+    "contains" : "indeholder",
+    "matches" : "er lig med",
     "Priority" : "Prioritet",
     "Reset" : "Nulstil",
     "Client ID" : "Klient-ID",
@@ -405,6 +405,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s"
+    "Continue to %s" : "Videre til %s",
+    "New test" : "Nyeste test",
+    "Actions" : "Handlinger",
+    "New action" : "Ny handling"
 },
 "nplurals=2; plural=(n != 1);");
