@@ -357,8 +357,10 @@ OC.L10N.register(
     "Translate from" : "Traducir desde",
     "Untitled event" : "Evento sin título",
     "(organizer)" : "(organizador)",
+    "Recipient" : "Destinatario",
     "Operator" : "Operador",
-    "Actions" : "Acciones",
+    "contains" : "contiene",
+    "matches" : "coincide",
     "Priority" : "Prioridad",
     "Reset" : "Reiniciar",
     "Client ID" : "ID del cliente",
@@ -393,6 +395,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
