@@ -340,6 +340,7 @@ OC.L10N.register(
     "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indekseering sinu kirju. Kui postkastid on väga suured, siis võib kuluda natuke aega.",
     "Choose target mailbox" : "Vali sihtpostkast",
     "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
+    "Important info" : "Oluline teave",
     "Other" : "Muu",
     "The sender of this message has asked to be notified when you read this message." : "Selle kirja saatja on palunud kinnitust, kui oled kirja lugenud.",
     "Notify the sender" : "Teavita saatjat",
@@ -354,6 +355,7 @@ OC.L10N.register(
     "Forward message as attachment" : "Edasta kiri manusena",
     "View source" : "Vaata kirja lähtekoodi",
     "Print message" : "Prindi kiri",
+    "Create mail filter" : "E-posti filtri koostamine",
     "Download thread data for debugging" : "Laadi jutulõnga andmed veaotsinguks ja silumiseks alla",
     "Message body" : "Kirja sisu",
     "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Hoiatus: Selle kirja S/MIME allkiri on verifitseerimata. Saatja võib esineda kellegi teisena!",
@@ -599,6 +601,10 @@ OC.L10N.register(
     "Delete action" : "Kustuta tegevus",
     "Flag" : "Märgi",
     "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
+    "Sender" : "Saatja",
+    "Recipient" : "Saaja",
+    "Create a new mail filter" : "Koosta uus e-posti filter",
+    "Choose the headers you want to use to create your filter. In the next step, you will be able to refine the filter conditions and specify the actions to be taken on messages that match your criteria." : "Vali päisekirjed, mida tahad oma filtri loomisel kasutada. Järgmises sammus saad filtrite tingimusi täpsustada ja määratleda tegevused, mida nende täitmisel tehakse.",
     "Delete filter" : "Kustuta filter",
     "Delete mail filter {filterName}?" : "Kas kustutame e-posti filtri „{filterName}“?",
     "Are you sure to delete the mail filter?" : "Kas sa oled kindel, et soovid selle e-postifiltri kustutada?",
@@ -611,19 +617,23 @@ OC.L10N.register(
     "Filter is active" : "Filter on kasutusel",
     "Filter is not active" : "Filter pole kasutusel",
     "Operator" : "Operaator",
-    "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
-    "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
+    "If all the conditions are met, the actions will be performed" : "Kui kõik tingimused vastavad siis, need tegevused käivitatakse",
+    "If any of the conditions are met, the actions will be performed" : "Kui mõni tingimus vastab siis, need tegevused käivitatakse",
+    "is exactly" : "on täpselt",
+    "contains" : "sisaldab",
+    "matches" : "kattub",
     "Delete test" : "Kustuta test",
     "Update mail filter" : "Uuenda e-posti filtrit",
     "Filter name" : "Filtri nimi",
-    "Tests" : "Testid",
-    "New test" : "Uus test",
-    "Actions" : "Tegevused",
+    "If all the conditions are met" : "Kui kõik tingimused on täidetud",
+    "If any of the conditions are met" : "Kui mõni tingimutest on täidetud",
+    "Add condition" : "Lisa tingimus",
+    "Then perform these actions" : "Seejärel käivita need tegevused",
     "Actions are triggered when the specified tests are true. The following actions are available:" : "Tegevused käivituvad, kui konkreetse testi vastus on tõene. Saadaval on järgnevad tegevused:",
     "Moves the message into a specified folder." : "Teisaldab kirja etteantud kausta.",
     "Adds a flag to the message." : "Lisab kirjale märgistuse.",
     "Halts the execution of the filter script. No further filters with will be processed after this action." : "Lõpetab Sieve skripti töö. Peale seda ei töödelda ühtegi järgnevat tingimust.",
-    "New action" : "Uus tegevus",
+    "Add action" : "Lisa tegevus",
     "Priority" : "Prioriteet",
     "Enable filter" : "Kasuta filtrit",
     "Save filter" : "Salvesta filter",
@@ -634,6 +644,7 @@ OC.L10N.register(
     "Mail app" : "E-posti rakendus",
     "The mail app allows users to read mails on their IMAP accounts." : "Selle rakendusega saavad kasutajad lugeda oma IMAP-i kontode kirju.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Siin on serverikohased seadistused. Kasutajakohased seadistused leiduvad rakenduses (vaata alumist vasakut nurka).",
+    "Add new config" : "Lisa uus konfiguratsioon",
     "Allow additional mail accounts" : "Lisa veel e-postikontosid",
     "Allow additional Mail accounts from User Settings" : "Luba kasutaja seadistustest täiendavate e-posti kontode kasutamine",
     "Enable text processing through LLMs" : "Kasuta teksti töötlemist suure keelemudeliga",
@@ -742,7 +753,11 @@ OC.L10N.register(
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
     "Continue to %s" : "Jätka siia: %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft libab kasutajatel lugeda kirju IMAP-i abil. Turvakaalutlustel toimib see vaid OAuth 2.0 liidestusega.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Sa pead Microsoft Azure Active Directory portaalis registreerima uue rakenduse. Korrektse suunamisaadressina kasuta: {url}"
+    "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
+    "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
+    "Tests" : "Testid",
+    "New test" : "Uus test",
+    "Actions" : "Tegevused",
+    "New action" : "Uus tegevus"
 },
 "nplurals=2; plural=(n != 1);");
