@@ -281,7 +281,8 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
     "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
     "Train" : "Vlak",
-    "Actions" : "Radnje",
+    "Recipient" : "Primatelj",
+    "matches" : "podudara se",
     "Priority" : "Prioritet",
     "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
     "Error saving config" : "Pogreška pri spremanju konfiguracije",
@@ -377,6 +378,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s"
+    "Continue to %s" : "Idi do %s",
+    "Actions" : "Radnje"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
