@@ -500,11 +500,12 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Vonat {depStation} és {arrStation} között",
     "Train" : "Vonat",
     "Flag" : "Zászló",
+    "Recipient" : "Címzett",
     "Delete filter" : "Szűrő törlése",
     "Operator" : "Állapot",
+    "contains" : "tartalmazza",
+    "matches" : "egyezik",
     "Filter name" : "Név szűrése",
-    "Actions" : "Műveletek",
-    "New action" : "Új művelet",
     "Priority" : "Prioritás",
     "Successfully updated config for \"{domain}\"" : "A(z) „{domain}” konfigurációja sikeresen frissítve",
     "Error saving config" : "Hiba a konfiguráció mentése során",
@@ -644,7 +645,7 @@ OC.L10N.register(
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
     "Continue to %s" : "Folytatás ide: %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "A Microsoft lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el a leveleiket. Biztonsági okokból ez a hozzáférés csak OAuth 2.0-s kapcsolaton lehetséges.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Regisztrálnia kell egy új alkalmazást a Microsoft Azure Active Directory portálon. Átirányítási URI-nak a következő webcímet adja meg: {url}"
+    "Actions" : "Műveletek",
+    "New action" : "Új művelet"
 },
 "nplurals=2; plural=(n != 1);");
