@@ -126,8 +126,10 @@ OC.L10N.register(
     "Tag already exists" : "Birka jau pastāv",
     "Not found" : "Nav atrasts",
     "Untitled event" : "Nenosaukts notikums",
+    "Recipient" : "Saņēmējs",
     "Operator" : "Operators",
-    "Actions" : "Darbības",
+    "contains" : "saturs",
+    "matches" : "atbilst",
     "Priority" : "Prioritāte",
     "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
@@ -160,6 +162,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Actions" : "Darbības"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
