@@ -573,11 +573,12 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}\n ",
     "Train" : "Tog",
     "Flag" : "Flagg",
+    "Recipient" : "Mottaker",
     "Delete filter" : "Slett filter",
     "Operator" : "Operator",
+    "contains" : "inneholder",
+    "matches" : "passer",
     "Filter name" : "Filternavn",
-    "Actions" : "Handlinger",
-    "New action" : "Ny handling",
     "Priority" : "Prioritet",
     "Successfully updated config for \"{domain}\"" : "Vellykket oppdatert konfigurasjon for «{domain}»",
     "Error saving config" : "Feil ved lagring av konfigurasjon",
@@ -726,7 +727,7 @@ OC.L10N.register(
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft lar brukere få tilgang til e-post via IMAP. Av sikkerhetsgrunner er denne tilgangen bare mulig med en OAuth 2.0-tilkobling.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Du må registrere en ny app i Microsoft Azure Active Directory-portalen. Legg til URL-adressen {url} som omdirigerings-URI."
+    "Actions" : "Handlinger",
+    "New action" : "Ny handling"
 },
 "nplurals=2; plural=(n != 1);");
