@@ -42,11 +42,11 @@ OC.L10N.register(
     "Close" : "වසන්න",
     "Body" : "අන්තර්ගතය",
     "Date" : "දිනය",
-    "Actions" : "ක්‍රියාමාර්ග",
     "User" : "පරිශීලක",
     "Host" : " ධාරකය",
     "Certificate" : "සහතිකය",
     "All" : "සියල්ල",
-    "Favorites" : "ප්‍රියතම"
+    "Favorites" : "ප්‍රියතම",
+    "Actions" : "ක්‍රියාමාර්ග"
 },
 "nplurals=2; plural=(n != 1);");
