@@ -3,37 +3,49 @@ OC.L10N.register(
     {
     "Work" : "Posao",
     "Mail" : "Pošta",
+    "Save" : "Save",
+    "Connect" : "Poveži se",
+    "Password required" : "Potrebna je lozinka",
     "Name" : "naziv",
     "Password" : "Password",
     "None" : "Ništa",
-    "Save" : "Save",
-    "Connect" : "Poveži se",
+    "Signature" : "Potpis",
     "Cancel" : "Otkaži",
-    "Select account" : "Označite nalog",
+    "General" : "Opšte",
+    "About" : "O programu",
+    "Delete" : "Delete",
+    "Search" : "Search",
     "Send" : "Pošalji",
+    "Refresh" : "Osveži",
+    "Select account" : "Označite nalog",
+    "Choose" : "Odaberi",
     "Favorite" : "Omiljene",
     "Read" : "Čitaj",
-    "Select" : "Obeleži",
-    "Move" : "Premesti",
-    "Forward" : "Prosledi",
+    "Back" : "Nazad",
+    "Description" : "Opis",
     "Create" : "Napravi",
+    "Select" : "Obeleži",
     "Comment" : "Komentar",
-    "Choose" : "Odaberi",
+    "Remove" : "Ukloni",
     "Other" : "Ostali",
-    "Reply" : "Odgovori",
+    "Forward" : "Prosledi",
+    "Translate" : "Prevedi",
+    "Move" : "Premesti",
+    "Loading …" : "Učitavanje...",
     "Remove account" : "Ukloni nalog",
     "Mark all as read" : "Označi sve kao pročitano",
+    "Rename" : "Preimenuj",
     "Clear cache" : "Očisti keš",
-    "Delete" : "Delete",
+    "Reply" : "Odgovori",
     "Add" : "Dodaj",
-    "Tags" : "Oznake",
-    "Search" : "Search",
+    "Close" : "Zatvori",
+    "Body" : "Telo",
     "Date" : "Date",
-    "Unset" : "Ukloni",
-    "Remove" : "Ukloni",
-    "General" : "Opšte",
+    "Tags" : "Oznake",
+    "Not found" : "Nije nađeno",
     "User" : "User",
-    "Refresh" : "Osveži",
-    "Favorites" : "Omiljene"
+    "All" : "Sve",
+    "Favorites" : "Omiljene",
+    "Continue to %s" : "Nastavi na %s"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
