@@ -67,7 +67,6 @@ OC.L10N.register(
     "Custom" : "กำหนดเอง",
     "Tag already exists" : "มีแท็กอยู่แล้ว",
     "Not found" : "ไม่พบ",
-    "Actions" : "การกระทำ",
     "Priority" : "ลำดับความสำคัญ",
     "Reset" : "ตั้งค่าใหม่",
     "Client ID" : "รหัสไคลเอ็นต์",
@@ -91,6 +90,7 @@ OC.L10N.register(
     "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
-    "Continue to %s" : "ดำเนินการต่อไปที่ %s"
+    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
+    "Actions" : "การกระทำ"
 },
 "nplurals=1; plural=0;");
