@@ -580,23 +580,19 @@ OC.L10N.register(
     "Filter is active" : "سۈزگۈچ ئاكتىپ",
     "Filter is not active" : "سۈزگۈچ ئاكتىپ ئەمەس",
     "Operator" : "Operator",
-    "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
-    "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
+    "contains" : "بار",
+    "matches" : "match",
     "Delete test" : "سىناقنى ئۆچۈرۈڭ",
     "Update mail filter" : "خەت سۈزگۈچنى يېڭىلاڭ",
     "Filter name" : "سۈزگۈچ ئىسمى",
-    "Tests" : "سىناق",
     "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "ئىمتىھان ئېلېكترونلۇق خەت مۇلازىمېتىرىڭىزدىكى كەلگەن ئېلېكترونلۇق خەتلەرگە ، تېما (ئېلېكترونلۇق خەتنىڭ تېما لىنىيىسى) ، (ئەۋەتكۈچى) ۋە (تاپشۇرۇۋالغۇچى) غا ئوخشاش ساھەگە ئىشلىتىلىدۇ. تۆۋەندىكى مەشغۇلاتلارنى ئىشلىتىپ بۇ ساھەنىڭ شەرتلىرىنى بەلگىلىيەلەيسىز:",
     "An exact match. The field must be identical to the provided value." : "ئېنىق ماس. بۇ ساھە چوقۇم تەمىنلەنگەن قىممەت بىلەن ئوخشاش بولۇشى كېرەك.",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Subring match. ئەگەر تەمىنلەنگەن قىممەت ئۇنىڭ ئىچىدە بولسا ، مەيدان ماس كېلىدۇ. مەسىلەن ، «دوكلات» «پورت» بىلەن ماس كېلىدۇ.",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ياۋايى كارتا ئىشلىتىپ ئەندىزە ماس كېلىدۇ. \"*\" بەلگىسى ھەرپ-بەلگىلەرنى كۆرسىتىدۇ (ھېچقايسىسىنى ئۆز ئىچىگە ئالمايدۇ) ، \"?\" دەل بىر ھەرپكە ۋەكىللىك قىلىدۇ. مەسىلەن ، «* دوكلات *» «سودا دوكلاتى 2024» بىلەن ماس كېلىدۇ.",
-    "New test" : "يېڭى سىناق",
-    "Actions" : "مەشغۇلاتلار",
     "Actions are triggered when the specified tests are true. The following actions are available:" : "كۆرسىتىلگەن سىناقلار توغرا بولغاندا ھەرىكەت قوزغىلىدۇ. تۆۋەندىكى ھەرىكەتلەر بار:",
     "Moves the message into a specified folder." : "ئۇچۇرنى بەلگىلەنگەن قىسقۇچقا يۆتكەيدۇ.",
     "Adds a flag to the message." : "ئۇچۇرغا بايراق قوشىدۇ.",
     "Halts the execution of the filter script. No further filters with will be processed after this action." : "سۈزگۈچ قوليازمىسىنىڭ ئىجرا قىلىنىشىنى توختىتىدۇ. بۇ ھەرىكەتتىن كېيىن باشقا سۈزگۈچلەر بىر تەرەپ قىلىنمايدۇ.",
-    "New action" : "يېڭى ھەرىكەت",
     "Priority" : "ھەممىدىن مۇھىم",
     "Enable filter" : "سۈزگۈچنى قوزغىتىڭ",
     "Save filter" : "سۈزگۈچنى ساقلاڭ",
@@ -745,7 +741,11 @@ OC.L10N.register(
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
     "Continue to %s" : "داۋاملىق% s",
-    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "مىكروسوفت ئىشلەتكۈچىلەرنىڭ ئېلېكترونلۇق خەتلىرىنى IMAP ئارقىلىق زىيارەت قىلالايدۇ. بىخەتەرلىك سەۋەبىدىن بۇ زىيارەت پەقەت OAuth 2.0 ئۇلىنىشى بىلەنلا مۇمكىن.",
-    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "Microsoft Azure ئاكتىپ مۇندەرىجە ئېغىزىدا يېڭى ئەپ تىزىملىتىشىڭىز كېرەك. URL {url} نى قايتا URI غا قوشۇڭ."
+    "If all tests pass, then the actions will be executed" : "ئەگەر بارلىق سىناقلار ئۆتۈپ كەتسە ، ھەرىكەتلەر ئىجرا بولىدۇ",
+    "If one test pass, then the actions will be executed" : "ئەگەر بىر سىناقتىن ئۆتسە ، ئۇنداقتا ھەرىكەت ئىجرا بولىدۇ",
+    "Tests" : "سىناق",
+    "New test" : "يېڭى سىناق",
+    "Actions" : "مەشغۇلاتلار",
+    "New action" : "يېڭى ھەرىكەت"
 },
 "nplurals=2; plural=(n != 1);");
