@@ -20,11 +20,14 @@ use Horde_Imap_Client_Search_Query;
 use Horde_Imap_Client_Socket;
 use Horde_Mime_Exception;
 use Horde_Mime_Headers;
+use Horde_Mime_Headers_ContentParam_ContentType;
+use Horde_Mime_Headers_ContentTransferEncoding;
 use Horde_Mime_Part;
 use Html2Text\Html2Text;
 use OCA\Mail\Attachment;
 use OCA\Mail\Db\Mailbox;
 use OCA\Mail\Exception\ServiceException;
+use OCA\Mail\Html\Parser;
 use OCA\Mail\IMAP\Charset\Converter;
 use OCA\Mail\Model\IMAPMessage;
 use OCA\Mail\Service\SmimeService;
@@ -144,6 +147,7 @@ class MessageMapper {
 		} else {
 			$max = ((int)$metaResults['max']);
 		}
+		unset($metaResults);
 
 		// The inclusive range of UIDs
 		$totalRange = $max - $min + 1;
@@ -159,7 +163,8 @@ class MessageMapper {
 		// Determine max UID to fetch, but don't exceed the known maximum
 		$upper = min(
 			$max,
-			$lower + $estimatedPageSize
+			$lower + $estimatedPageSize,
+			$lower + 1_000_000, // Somewhat sensible number of UIDs that fit into memory (Horde_Imap_ClientId bloat)
 		);
 		if ($lower > $upper) {
 			$logger->debug("Range for findAll did not find any (not already known) messages and all messages of mailbox $mailbox have been fetched.");
@@ -170,7 +175,22 @@ class MessageMapper {
 			];
 		}
 
-		$logger->debug("Built range for findAll: min=$min max=$max total=$total totalRange=$totalRange estimatedPageSize=$estimatedPageSize lower=$lower upper=$upper highestKnownUid=$highestKnownUid");
+		$idsToFetch = new Horde_Imap_Client_Ids($lower . ':' . $upper);
+		$actualPageSize = $this->getPageSize($client, $mailbox, $idsToFetch);
+		$logger->debug("Built range for findAll: min=$min max=$max total=$total totalRange=$totalRange estimatedPageSize=$estimatedPageSize actualPageSize=$actualPageSize lower=$lower upper=$upper highestKnownUid=$highestKnownUid");
+		while ($actualPageSize > $maxResults) {
+			$logger->debug("Range for findAll matches too many messages: min=$min max=$max total=$total estimatedPageSize=$estimatedPageSize actualPageSize=$actualPageSize");
+
+			$estimatedPageSize = (int)($estimatedPageSize / 2);
+
+			$upper = min(
+				$max,
+				$lower + $estimatedPageSize,
+				$lower + 1_000_000, // Somewhat sensible number of UIDs that fit into memory (Horde_Imap_ClientId bloat)
+			);
+			$idsToFetch = new Horde_Imap_Client_Ids($lower . ':' . $upper);
+			$actualPageSize = $this->getPageSize($client, $mailbox, $idsToFetch);
+		}
 
 		$query = new Horde_Imap_Client_Fetch_Query();
 		$query->uid();
@@ -178,7 +198,7 @@ class MessageMapper {
 			$mailbox,
 			$query,
 			[
-				'ids' => new Horde_Imap_Client_Ids($lower . ':' . $upper)
+				'ids' => $idsToFetch
 			]
 		);
 		$perf->step('fetch UIDs');
@@ -192,6 +212,9 @@ class MessageMapper {
 			 * there is nothing to fetch in $highestKnownUid:$upper
 			 */
 			$logger->debug('Range for findAll did not find any messages. Trying again with a succeeding range');
+			// Clean up some unused variables before recursion
+			unset($fetchResult, $idsToFetch, $query);
+			$perf->step('free memory before recursion');
 			return $this->findAll($client, $mailbox, $maxResults, $upper, $logger, $perf, $userId);
 		}
 		$uidCandidates = array_filter(
@@ -888,15 +911,13 @@ class MessageMapper {
 			$structure = $fetchData->getStructure();
 
 			/** @var Horde_Mime_Part $part */
-			foreach ($structure->getParts() as $part) {
+			foreach ($structure->partIterator() as $part) {
 				if ($part->isAttachment()) {
 					$hasAttachments = true;
 				}
-				$bodyParts = $part->getParts();
-				/** @var Horde_Mime_Part $bodyPart */
-				foreach ($bodyParts as $bodyPart) {
-					$contentParameters = $bodyPart->getAllContentTypeParameters();
-					if ($bodyPart->getType() === 'text/calendar' && isset($contentParameters['method'])) {
+
+				if ($part->getType() === 'text/calendar') {
+					if ($part->getContentTypeParameter('method') !== null) {
 						$isImipMessage = true;
 					}
 				}
@@ -934,15 +955,39 @@ class MessageMapper {
 				return new MessageStructureData($hasAttachments, $text, $isImipMessage, $isEncrypted, false);
 			}
 
+			// Convert a given binary body to utf-8 according to the transfer encoding and content
+			// type headers of the underlying MIME part
+			$convertBody = function (string $body, Horde_Mime_Headers $mimeHeaders) use ($structure): string {
+				/** @var Horde_Mime_Headers_ContentParam_ContentType $contentType */
+				$contentType = $mimeHeaders->getHeader('content-type');
+				/** @var Horde_Mime_Headers_ContentTransferEncoding $transferEncoding */
+				$transferEncoding = $mimeHeaders->getHeader('content-transfer-encoding');
+
+				if (!$contentType && !$transferEncoding) {
+					// Nothing to convert here ...
+					return $body;
+				}
+
+				if ($transferEncoding) {
+					$structure->setTransferEncoding($transferEncoding->value_single);
+				}
+
+				if ($contentType) {
+					$structure->setType($contentType->value_single);
+					if (isset($contentType['charset'])) {
+						$structure->setCharset($contentType['charset']);
+					}
+				}
+
+				$structure->setContents($body);
+				return $this->converter->convert($structure);
+			};
+
 
 			$htmlBody = ($htmlBodyId !== null) ? $part->getBodyPart($htmlBodyId) : null;
 			if (!empty($htmlBody)) {
 				$mimeHeaders = $part->getMimeHeader($htmlBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-					$structure->setTransferEncoding($enc);
-					$structure->setContents($htmlBody);
-					$htmlBody = $this->converter->convert($structure);
-				}
+				$htmlBody = $convertBody($htmlBody, $mimeHeaders);
 				$mentionsUser = $this->checkLinks($htmlBody, $emailAddress);
 				$html = new Html2Text($htmlBody, ['do_links' => 'none','alt_image' => 'hide']);
 				return new MessageStructureData(
@@ -957,11 +1002,7 @@ class MessageMapper {
 
 			if (!empty($textBody)) {
 				$mimeHeaders = $part->getMimeHeader($textBodyId, Horde_Imap_Client_Data_Fetch::HEADER_PARSE);
-				if ($enc = $mimeHeaders->getValue('content-transfer-encoding')) {
-					$structure->setTransferEncoding($enc);
-					$structure->setContents($textBody);
-					$textBody = $this->converter->convert($structure);
-				}
+				$textBody = $convertBody($textBody, $mimeHeaders);
 				return new MessageStructureData(
 					$hasAttachments,
 					$textBody,
@@ -977,10 +1018,7 @@ class MessageMapper {
 		if (empty($body)) {
 			return false;
 		}
-		$dom = new \DOMDocument();
-		libxml_use_internal_errors(true);
-		$dom->loadHTML($body);
-		libxml_use_internal_errors();
+		$dom = Parser::parseToDomDocument($body);
 		$anchors = $dom->getElementsByTagName('a');
 		foreach ($anchors as $anchor) {
 			$href = $anchor->getAttribute('href');
@@ -990,4 +1028,21 @@ class MessageMapper {
 		}
 		return false;
 	}
+
+	private function getPageSize(Horde_Imap_Client_Socket $client,
+		string $mailbox,
+		Horde_Imap_Client_Ids $idsToFetch): int {
+		$rangeSearchQuery = new Horde_Imap_Client_Search_Query();
+		$rangeSearchQuery->ids($idsToFetch);
+		$rangeSearchResult = $client->search(
+			$mailbox,
+			$rangeSearchQuery,
+			[
+				'results' => [
+					Horde_Imap_Client::SEARCH_RESULTS_COUNT,
+				],
+			]
+		);
+		return (int)$rangeSearchResult['count'];
+	}
 }
